import math
import json 

def paginate(totalItems, currentPage=1, pageSize=10, maxPages=10):
    # calculate total pages
    totalPages = math.ceil(totalItems / pageSize)

    # ensure current page isn't out of range
    if currentPage < 1:
        currentPage = 1
    elif currentPage > totalPages:
        currentPage = totalPages

    global startPage
    global endPage

    if totalPages <= maxPages:
        startPage = 1
        endPage = totalPages
    else: 
        maxPagesBeforeCurrentPage = math.floor(maxPages / 2)
        maxPagesAfterCurrentPage = math.ceil(maxPages / 2) - 1
        if currentPage <= maxPagesBeforeCurrentPage: 
            # current page near the start
            startPage = 1
            endPage = maxPages
        elif currentPage + maxPagesAfterCurrentPage >= totalPages:
            # current page near the end
            startPage = totalPages - maxPages + 1
            endPage = totalPages
        else:
            # current page somewhere in the middle
            startPage = currentPage - maxPagesBeforeCurrentPage
            endPage = currentPage + maxPagesAfterCurrentPage
    

    # calculate start and end item indexes
    startIndex = (currentPage - 1) * pageSize
    endIndex = min(startIndex + pageSize - 1, totalItems - 1)

    pages = []
    # create an array of pages to ng-repeat in the pager control
    for i in range(startPage, endPage+1):
        pages.append(i)
        
    # return object with all pager properties required by the view
    res = {}
    res['totalItems'] = int(totalItems)
    res['currentPage'] = int(currentPage)
    res['pageSize'] = int(pageSize)
    res['totalPages'] = int(totalPages)
    res['startPage'] = int(startPage)
    res['endPage'] = int(endPage)
    res['startIndex'] = int(startIndex)
    res['endIndex'] = int(endIndex)
    res['pages'] = pages

    return json.dumps(res)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pypagination",
    version="0.0.3",
    author="Mishal Shah",
    author_email="mshah31@asu.edu",
    description="A small library to paginate through json objects",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mishal9/pypagination/issues",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.6, !=3.0.*, !=3.1.*, !=3.2.*, <4',
)